@@ -17,13 +17,13 @@
 %                              May  1993                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -72,6 +72,9 @@ struct _Ascii85Info
     offset,
     line_break;
 
+  char
+    tuple[6];
+
   unsigned char
     buffer[10];
 };
@@ -88,11 +91,11 @@ typedef struct HuffmanTable
 /*
   Huffman coding declarations.
 */
-#define TWId  23
-#define MWId  24
-#define TBId  25
-#define MBId  26
-#define EXId  27
+#define TWId  23L
+#define MWId  24L
+#define TBId  25L
+#define MBId  26L
+#define EXId  27L
 
 static const HuffmanTable
   MBTable[]=
@@ -225,13 +228,11 @@ static const HuffmanTable
 %
 %
 */
-#define MaxLineExtent  36
+#define MaxLineExtent  36L
 
-static char *Ascii85Tuple(unsigned char *data)
+static inline void Ascii85Tuple(Ascii85Info *ascii85_info,
+  const unsigned char *magick_restrict data)
 {
-  static char
-    tuple[6];
-
   register ssize_t
     i,
     x;
@@ -244,21 +245,20 @@ static char *Ascii85Tuple(unsigned char *data)
     ((size_t) data[2] << 8) | (size_t) data[3];
   if (code == 0L)
     {
-      tuple[0]='z';
-      tuple[1]='\0';
-      return(tuple);
+      ascii85_info->tuple[0]='z';
+      ascii85_info->tuple[1]='\0';
+      return;
     }
   quantum=85UL*85UL*85UL*85UL;
   for (i=0; i < 4; i++)
   {
     x=(ssize_t) (code/quantum);
     code-=quantum*x;
-    tuple[i]=(char) (x+(int) '!');
+    ascii85_info->tuple[i]=(char) (x+(int) '!');
     quantum/=85L;
   }
-  tuple[4]=(char) ((code % 85L)+(int) '!');
-  tuple[5]='\0';
-  return(tuple);
+  ascii85_info->tuple[4]=(char) ((code % 85L)+(int) '!');
+  ascii85_info->tuple[5]='\0';
 }
 
 MagickExport void Ascii85Initialize(Image *image)
@@ -271,15 +271,12 @@ MagickExport void Ascii85Initialize(Image *image)
   if (image->ascii85 == (Ascii85Info *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) memset(image->ascii85,0,sizeof(*image->ascii85));
-  image->ascii85->line_break=(ssize_t) MaxLineExtent << 1;
+  image->ascii85->line_break=(ssize_t) (MaxLineExtent << 1);
   image->ascii85->offset=0;
 }
 
 MagickExport void Ascii85Flush(Image *image)
 {
-  register char
-    *tuple;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
@@ -290,9 +287,10 @@ MagickExport void Ascii85Flush(Image *image)
       image->ascii85->buffer[image->ascii85->offset]='\0';
       image->ascii85->buffer[image->ascii85->offset+1]='\0';
       image->ascii85->buffer[image->ascii85->offset+2]='\0';
-      tuple=Ascii85Tuple(image->ascii85->buffer);
+      Ascii85Tuple(image->ascii85,image->ascii85->buffer);
       (void) WriteBlob(image,(size_t) image->ascii85->offset+1,
-        (const unsigned char *) (*tuple == 'z' ? "!!!!" : tuple));
+        (const unsigned char *) (*image->ascii85->tuple == 'z' ? "!!!!" :
+        image->ascii85->tuple));
     }
   (void) WriteBlobByte(image,'~');
   (void) WriteBlobByte(image,'>');
@@ -320,7 +318,8 @@ MagickExport void Ascii85Encode(Image *image,const unsigned char code)
   p=image->ascii85->buffer;
   for (n=image->ascii85->offset; n >= 4; n-=4)
   {
-    for (q=Ascii85Tuple(p); *q != '\0'; q++)
+    Ascii85Tuple(image->ascii85,p);
+    for (q=image->ascii85->tuple; *q != '\0'; q++)
     {
       image->ascii85->line_break--;
       if ((image->ascii85->line_break < 0) && (*q != '%'))
@@ -366,11 +365,11 @@ MagickExport void Ascii85Encode(Image *image,const unsigned char code)
 MagickExport MagickBooleanType HuffmanDecodeImage(Image *image,
   ExceptionInfo *exception)
 {
-#define HashSize  1021
-#define MBHashA  293
-#define MBHashB  2695
-#define MWHashA  3510
-#define MWHashB  1178
+#define HashSize  1021L
+#define MBHashA  293L
+#define MBHashB  2695L
+#define MWHashA  3510L
+#define MWHashB  1178L
 
 #define InitializeHashTable(hash,table,a,b) \
 { \
@@ -553,7 +552,7 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image,
       if (length > 13)
         {
           while (runlength < 11)
-           InputBit(bit);
+            InputBit(bit);
           do { InputBit(bit); } while ((int) bit == 0);
           break;
         }
@@ -590,7 +589,8 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image,
                 }
               else
                 for ( ; count > 0; count--)
-                  scanline[x++]=(unsigned char) 1;
+                  if ((x >= 0) && (x < (ssize_t) image->columns))
+                    scanline[x++]=(unsigned char) 1;
             }
           color=(unsigned int)
             ((color == MagickFalse) ? MagickTrue : MagickFalse);
