@@ -63,6 +63,7 @@
 #include "MagickCore/resource_.h"
 #include "MagickCore/splay-tree.h"
 #include "MagickCore/string_.h"
+#include "MagickCore/string-private.h"
 #include "MagickCore/thread-private.h"
 #include "MagickCore/token.h"
 #include "MagickCore/utility.h"
@@ -373,12 +374,38 @@ MagickExport char *GetNextImageProfile(const Image *image)
 */
 
 #if defined(MAGICKCORE_LCMS_DELEGATE)
+
+#if LCMS_VERSION < 2060
+static void* cmsGetContextUserData(cmsContext ContextID)
+{
+  return(ContextID);
+}
+
+static cmsContext cmsCreateContext(void *magick_unused(Plugin),void *UserData)
+{
+  magick_unreferenced(Plugin);
+  return((cmsContext) UserData);
+}
+
+static void cmsSetLogErrorHandlerTHR(cmsContext magick_unused(ContextID),
+  cmsLogErrorHandlerFunction Fn)
+{
+  magick_unreferenced(ContextID);
+  cmsSetLogErrorHandler(Fn);
+}
+
+static void cmsDeleteContext(cmsContext magick_unused(ContextID))
+{
+  magick_unreferenced(ContextID);
+}
+#endif
+
 static LCMSType **DestroyPixelThreadSet(LCMSType **pixels)
 {
   register ssize_t
     i;
 
-  if (pixels != (LCMSType **) NULL)
+  if (pixels == (LCMSType **) NULL)
     return((LCMSType **) NULL);
   for (i=0; i < (ssize_t) GetMagickResourceLimit(ThreadResource); i++)
     if (pixels[i] != (LCMSType *) NULL)
@@ -456,9 +483,7 @@ static cmsHTRANSFORM *AcquireTransformThreadSet(
   }
   return(transform);
 }
-#endif
 
-#if defined(MAGICKCORE_LCMS_DELEGATE)
 static void CMSExceptionHandler(cmsContext context,cmsUInt32Number severity,
   const char *message)
 {
@@ -1739,9 +1764,9 @@ static MagickBooleanType ValidateXMPProfile(const StringInfo *profile)
   char
     *p;
 
-  p=strcasestr((const char *) GetStringInfoDatum(profile),"x:xmpmeta");
+  p=StringLocateSubstring((const char *) GetStringInfoDatum(profile),"x:xmpmeta");
   if (p != (char *) NULL)
-    p=strcasestr((const char *) GetStringInfoDatum(profile),"rdf:RDF");
+    p=StringLocateSubstring((const char *) GetStringInfoDatum(profile),"rdf:RDF");
   return(p == (char *) NULL ? MagickFalse : MagickTrue);
 }
 #endif
