@@ -71,6 +71,8 @@
   Define declarations.
 */
 #define MagickPathTemplate "XXXXXXXXXXXX"
+#define NumberOfResourceTypes  \
+  (sizeof(resource_semaphore)/sizeof(*resource_semaphore))
 
 /*
   Typedef declarations.
@@ -138,7 +140,20 @@ static ResourceInfo
   };
 
 static SemaphoreInfo
-  *resource_semaphore = (SemaphoreInfo *) NULL;
+  *resource_semaphore[] = {
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL,
+     (SemaphoreInfo *) NULL
+  };
 
 static SplayTreeInfo
   *temporary_resources = (SplayTreeInfo *) NULL;
@@ -188,76 +203,35 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
   if (request < 0)
     return(MagickFalse);
   limit=0;
+  current=0;
   bi=MagickFalse;
   status=MagickFalse;
   switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
+    {
+      if (resource_semaphore[type] == (SemaphoreInfo *) NULL)
+        ActivateSemaphoreInfo(&resource_semaphore[type]);
+      LockSemaphoreInfo(resource_semaphore[type]);
+      break;
+    }
+    default: ;
+  }
+  switch (type)
   {
     case AreaResource:
     {
       bi=MagickTrue;
       resource_info.area=request;
       limit=resource_info.area_limit;
-      break;
-    }
-    case HeightResource:
-    {
-      bi=MagickTrue;
-      resource_info.height=request;
-      limit=resource_info.height_limit;
-      break;
-    }
-    case ListLengthResource:
-    {
-      resource_info.list_length=request;
-      limit=resource_info.list_length_limit;
-      break;
-    }
-    case ThreadResource:
-    {
-      limit=resource_info.thread_limit;
-      break;
-    }
-    case ThrottleResource:
-    {
-      limit=resource_info.throttle_limit;
-      break;
-    }
-    case WidthResource:
-    {
-      bi=MagickTrue;
-      resource_info.width=request;
-      limit=resource_info.width_limit;
-      break;
-    }
-    default:
-      break;
-  }
-  if (limit != 0)
-    {
       if ((limit == MagickResourceInfinity) || (size < limit))
         status=MagickTrue;
-      if (IsEventLogging() != MagickFalse)
-        {
-          char
-            resource_limit[MagickFormatExtent],
-            resource_request[MagickFormatExtent];
-
-          (void) FormatMagickSize(size,MagickFalse,(bi != MagickFalse) ?
-            "P" : (const char *) NULL,MagickFormatExtent,resource_request);
-          (void) FormatMagickSize((MagickSizeType) limit,MagickFalse,
-            (bi != MagickFalse) ? "P" : (const char *) NULL,
-            MagickFormatExtent,resource_limit);
-          (void) LogMagickEvent(ResourceEvent,GetMagickModule(),"%s: %s/%s",
-            CommandOptionToMnemonic(MagickResourceOptions,(ssize_t) type),
-            resource_request,resource_limit);
-        }
-      return(status);
+      break;
     }
-  if (resource_semaphore == (SemaphoreInfo *) NULL)
-    ActivateSemaphoreInfo(&resource_semaphore);
-  LockSemaphoreInfo(resource_semaphore);
-  switch (type)
-  {
     case DiskResource:
     {
       bi=MagickTrue;
@@ -287,6 +261,23 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       current=resource_info.file;
       break;
     }
+    case HeightResource:
+    {
+      bi=MagickTrue;
+      resource_info.height=request;
+      limit=resource_info.height_limit;
+      if ((limit == MagickResourceInfinity) || (size < limit))
+        status=MagickTrue;
+      break;
+    }
+    case ListLengthResource:
+    {
+      resource_info.list_length=request;
+      limit=resource_info.list_length_limit;
+      if ((limit == MagickResourceInfinity) || (size < limit))
+        status=MagickTrue;
+      break;
+    }
     case MapResource:
     {
       bi=MagickTrue;
@@ -319,6 +310,22 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       current=resource_info.memory;
       break;
     }
+    case ThreadResource:
+    {
+      limit=resource_info.thread_limit;
+      if ((limit == MagickResourceInfinity) ||
+          (resource_info.thread < (MagickOffsetType) limit))
+        status=MagickTrue;
+      break;
+    }
+    case ThrottleResource:
+    {
+      limit=resource_info.throttle_limit;
+      if ((limit == MagickResourceInfinity) ||
+          (resource_info.throttle < (MagickOffsetType) limit))
+        status=MagickTrue;
+      break;
+    }
     case TimeResource:
     {
       limit=resource_info.time_limit;
@@ -334,13 +341,34 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
       current=resource_info.time;
       break;
     }
+    case WidthResource:
+    {
+      bi=MagickTrue;
+      resource_info.width=request;
+      limit=resource_info.width_limit;
+      if ((limit == MagickResourceInfinity) || (size < limit))
+        status=MagickTrue;
+      break;
+    }
     default:
     {
       current=0;
       break;
     }
   }
-  UnlockSemaphoreInfo(resource_semaphore);
+  switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
+    {
+      UnlockSemaphoreInfo(resource_semaphore[type]);
+      break;
+    }
+    default: ;
+  }
   if (IsEventLogging() != MagickFalse)
     {
       char
@@ -550,12 +578,12 @@ MagickExport int AcquireUniqueFileResource(char *path)
   (void) LogMagickEvent(ResourceEvent,GetMagickModule(),"...");
   if (random_info == (RandomInfo *) NULL)
     {
-      if (resource_semaphore == (SemaphoreInfo *) NULL)
-        ActivateSemaphoreInfo(&resource_semaphore);
-      LockSemaphoreInfo(resource_semaphore);
+      if (resource_semaphore[FileResource] == (SemaphoreInfo *) NULL)
+        ActivateSemaphoreInfo(&resource_semaphore[FileResource]);
+      LockSemaphoreInfo(resource_semaphore[FileResource]);
       if (random_info == (RandomInfo *) NULL)
         random_info=AcquireRandomInfo();
-      UnlockSemaphoreInfo(resource_semaphore);
+      UnlockSemaphoreInfo(resource_semaphore[FileResource]);
     }
   file=(-1);
   for (i=0; i < (ssize_t) TMP_MAX; i++)
@@ -606,13 +634,13 @@ MagickExport int AcquireUniqueFileResource(char *path)
   (void) LogMagickEvent(ResourceEvent,GetMagickModule(),"%s",path);
   if (file == -1)
     return(file);
-  if (resource_semaphore == (SemaphoreInfo *) NULL)
-    ActivateSemaphoreInfo(&resource_semaphore);
-  LockSemaphoreInfo(resource_semaphore);
+  if (resource_semaphore[FileResource] == (SemaphoreInfo *) NULL)
+    ActivateSemaphoreInfo(&resource_semaphore[FileResource]);
+  LockSemaphoreInfo(resource_semaphore[FileResource]);
   if (temporary_resources == (SplayTreeInfo *) NULL)
     temporary_resources=NewSplayTree(CompareSplayTreeString,
       DestroyTemporaryResources,(void *(*)(void *)) NULL);
-  UnlockSemaphoreInfo(resource_semaphore);
+  UnlockSemaphoreInfo(resource_semaphore[FileResource]);
   (void) AddValueToSplayTree(temporary_resources,ConstantString(path),
     (const void *) NULL);
   return(file);
@@ -647,12 +675,37 @@ MagickExport MagickSizeType GetMagickResource(const ResourceType type)
 
   resource=0;
   switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
+    {
+      if (resource_semaphore[type] == (SemaphoreInfo *) NULL)
+        ActivateSemaphoreInfo(&resource_semaphore[type]);
+      LockSemaphoreInfo(resource_semaphore[type]);
+      break;
+    }
+    default: ;
+  }
+  switch (type)
   {
     case AreaResource:
     {
       resource=(MagickSizeType) resource_info.area;
       break;
     }
+    case DiskResource:
+    {
+      resource=(MagickSizeType) resource_info.disk;
+      break;
+    }
+    case FileResource:
+    {
+      resource=(MagickSizeType) resource_info.file;
+      break;
+    }
     case HeightResource:
     {
       resource=(MagickSizeType) resource_info.height;
@@ -663,6 +716,21 @@ MagickExport MagickSizeType GetMagickResource(const ResourceType type)
       resource=(MagickSizeType) resource_info.list_length;
       break;
     }
+    case MapResource:
+    {
+      resource=(MagickSizeType) resource_info.map;
+      break;
+    }
+    case MemoryResource:
+    {
+      resource=(MagickSizeType) resource_info.memory;
+      break;
+    }
+    case TimeResource:
+    {
+      resource=(MagickSizeType) resource_info.time;
+      break;
+    }
     case ThreadResource:
     {
       resource=(MagickSizeType) resource_info.thread;
@@ -679,43 +747,20 @@ MagickExport MagickSizeType GetMagickResource(const ResourceType type)
       break;
     }
     default:
+      break;
+  }
+  switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
     {
-      if (resource_semaphore == (SemaphoreInfo *) NULL)
-        ActivateSemaphoreInfo(&resource_semaphore);
-      LockSemaphoreInfo(resource_semaphore);
-      switch (type)
-      {
-        case DiskResource:
-        {
-          resource=(MagickSizeType) resource_info.disk;
-          break;
-        }
-        case FileResource:
-        {
-          resource=(MagickSizeType) resource_info.file;
-          break;
-        }
-        case MapResource:
-        {
-          resource=(MagickSizeType) resource_info.map;
-          break;
-        }
-        case MemoryResource:
-        {
-          resource=(MagickSizeType) resource_info.memory;
-          break;
-        }
-        case TimeResource:
-        {
-          resource=(MagickSizeType) resource_info.time;
-          break;
-        }
-        default:
-          break;
-      }
-      UnlockSemaphoreInfo(resource_semaphore);
+      UnlockSemaphoreInfo(resource_semaphore[type]);
       break;
     }
+    default: ;
   }
   return(resource);
 }
@@ -746,15 +791,29 @@ MagickExport MagickSizeType GetMagickResourceLimit(const ResourceType type)
 {
   MagickSizeType
     resource;
-
-  resource=0;
+  
   switch (type)
   {
     case AreaResource:
-    {
-      resource=resource_info.area_limit;
-      break;
-    }
+      return resource_info.area_limit;
+    case HeightResource:
+      return resource_info.height_limit;
+    case ListLengthResource:
+      return resource_info.list_length_limit;
+    case ThreadResource:
+      return resource_info.thread_limit;
+    case ThrottleResource:
+      return resource_info.throttle_limit;
+    case WidthResource:
+      return resource_info.width_limit;
+    default: ;
+  }
+  resource=0;
+  if (resource_semaphore[type] == (SemaphoreInfo *) NULL)
+    ActivateSemaphoreInfo(&resource_semaphore[type]);
+  LockSemaphoreInfo(resource_semaphore[type]);
+  switch (type)
+  {
     case DiskResource:
     {
       resource=resource_info.disk_limit;
@@ -765,14 +824,9 @@ MagickExport MagickSizeType GetMagickResourceLimit(const ResourceType type)
       resource=resource_info.file_limit;
       break;
     }
-    case HeightResource:
+    case MapResource:
     {
-      resource=resource_info.height_limit;
-      break;
-    }
-    case ListLengthResource:
-    {
-      resource=resource_info.list_length_limit;
+      resource=resource_info.map_limit;
       break;
     }
     case MemoryResource:
@@ -780,34 +834,15 @@ MagickExport MagickSizeType GetMagickResourceLimit(const ResourceType type)
       resource=resource_info.memory_limit;
       break;
     }
-    case MapResource:
-    {
-      resource=resource_info.map_limit;
-      break;
-    }
-    case ThreadResource:
-    {
-      resource=resource_info.thread_limit;
-      break;
-    }
-    case ThrottleResource:
-    {
-      resource=resource_info.throttle_limit;
-      break;
-    }
     case TimeResource:
     {
       resource=resource_info.time_limit;
       break;
     }
-    case WidthResource:
-    {
-      resource=resource_info.width_limit;
-      break;
-    }
     default:
       break;
   }
+  UnlockSemaphoreInfo(resource_semaphore[type]);
   return(resource);
 }
 
@@ -843,6 +878,7 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
     area_limit[MagickFormatExtent],
     disk_limit[MagickFormatExtent],
     height_limit[MagickFormatExtent],
+    list_length_limit[MagickFormatExtent],
     map_limit[MagickFormatExtent],
     memory_limit[MagickFormatExtent],
     time_limit[MagickFormatExtent],
@@ -852,15 +888,19 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
 
   if (file == (const FILE *) NULL)
     file=stdout;
-  if (resource_semaphore == (SemaphoreInfo *) NULL)
-    ActivateSemaphoreInfo(&resource_semaphore);
-  LockSemaphoreInfo(resource_semaphore);
+  if (resource_semaphore[FileResource] == (SemaphoreInfo *) NULL)
+    ActivateSemaphoreInfo(&resource_semaphore[FileResource]);
+  LockSemaphoreInfo(resource_semaphore[FileResource]);
   (void) FormatMagickSize(resource_info.width_limit,MagickFalse,"P",
     MagickFormatExtent,width_limit);
   (void) FormatMagickSize(resource_info.height_limit,MagickFalse,"P",
     MagickFormatExtent,height_limit);
   (void) FormatMagickSize(resource_info.area_limit,MagickFalse,"P",
     MagickFormatExtent,area_limit);
+  (void) CopyMagickString(list_length_limit,"unlimited",MagickFormatExtent);
+  if (resource_info.list_length_limit != MagickResourceInfinity)
+    (void) FormatMagickSize(resource_info.list_length_limit,MagickTrue,"B",
+      MagickFormatExtent,list_length_limit);
   (void) FormatMagickSize(resource_info.memory_limit,MagickTrue,"B",
     MagickFormatExtent,memory_limit);
   (void) FormatMagickSize(resource_info.map_limit,MagickTrue,"B",
@@ -876,9 +916,8 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   (void) FormatLocaleFile(file,"Resource limits:\n");
   (void) FormatLocaleFile(file,"  Width: %s\n",width_limit);
   (void) FormatLocaleFile(file,"  Height: %s\n",height_limit);
-  (void) FormatLocaleFile(file,"  List length: %.20g\n",(double)
-    ((MagickOffsetType) resource_info.list_length_limit));
   (void) FormatLocaleFile(file,"  Area: %s\n",area_limit);
+  (void) FormatLocaleFile(file,"  List length: %s\n",list_length_limit);
   (void) FormatLocaleFile(file,"  Memory: %s\n",memory_limit);
   (void) FormatLocaleFile(file,"  Map: %s\n",map_limit);
   (void) FormatLocaleFile(file,"  Disk: %s\n",disk_limit);
@@ -890,7 +929,7 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
     ((MagickOffsetType) resource_info.throttle_limit));
   (void) FormatLocaleFile(file,"  Time: %s\n",time_limit);
   (void) fflush(file);
-  UnlockSemaphoreInfo(resource_semaphore);
+  UnlockSemaphoreInfo(resource_semaphore[FileResource]);
   return(MagickTrue);
 }
 
@@ -929,23 +968,24 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
     current,
     limit;
 
-  switch (type)
-  {
-    case AreaResource:
-    case HeightResource:
-    case ListLengthResource:
-    case ThreadResource:
-    case ThrottleResource:
-    case WidthResource:
-      return;
-    default:
-      break;
-  }
   bi=MagickFalse;
   limit=0;
-  if (resource_semaphore == (SemaphoreInfo *) NULL)
-    ActivateSemaphoreInfo(&resource_semaphore);
-  LockSemaphoreInfo(resource_semaphore);
+  current=0;
+  switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
+    {
+      if (resource_semaphore[type] == (SemaphoreInfo *) NULL)
+        ActivateSemaphoreInfo(&resource_semaphore[type]);
+      LockSemaphoreInfo(resource_semaphore[type]);
+      break;
+    }
+    default: ;
+  }
   switch (type)
   {
     case DiskResource:
@@ -998,7 +1038,19 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
       break;
     }
   }
-  UnlockSemaphoreInfo(resource_semaphore);
+  switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
+    {
+      UnlockSemaphoreInfo(resource_semaphore[type]);
+      break;
+    }
+    default: ;
+  }
   if (IsEventLogging() != MagickFalse)
     {
       char
@@ -1051,12 +1103,12 @@ MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
   assert(path != (const char *) NULL);
   status=MagickFalse;
   (void) LogMagickEvent(ResourceEvent,GetMagickModule(),"%s",path);
-  if (resource_semaphore == (SemaphoreInfo *) NULL)
-    ActivateSemaphoreInfo(&resource_semaphore);
-  LockSemaphoreInfo(resource_semaphore);
+  if (resource_semaphore[FileResource] == (SemaphoreInfo *) NULL)
+    ActivateSemaphoreInfo(&resource_semaphore[FileResource]);
+  LockSemaphoreInfo(resource_semaphore[FileResource]);
   if (temporary_resources != (SplayTreeInfo *) NULL)
     status=DeleteNodeFromSplayTree(temporary_resources,(const void *) path);
-  UnlockSemaphoreInfo(resource_semaphore);
+  UnlockSemaphoreInfo(resource_semaphore[FileResource]);
   (void) CopyMagickString(cache_path,path,MagickPathExtent);
   AppendImageFormat("cache",cache_path);
   if (access_utf8(cache_path,F_OK) == 0)
@@ -1093,6 +1145,9 @@ MagickPrivate MagickBooleanType ResourceComponentGenesis(void)
   MagickSizeType
     memory;
 
+  register ssize_t
+    i;
+
   ssize_t
     files,
     pages,
@@ -1101,8 +1156,9 @@ MagickPrivate MagickBooleanType ResourceComponentGenesis(void)
   /*
     Set Magick resource limits.
   */
-  if (resource_semaphore == (SemaphoreInfo *) NULL)
-    resource_semaphore=AcquireSemaphoreInfo();
+  for (i=0; i < (ssize_t) NumberOfResourceTypes; i++)
+    if (resource_semaphore[i] == (SemaphoreInfo *) NULL)
+      resource_semaphore[i]=AcquireSemaphoreInfo();
   (void) SetMagickResourceLimit(WidthResource,resource_info.width_limit);
   limit=GetEnvironmentValue("MAGICK_WIDTH_LIMIT");
   if (limit != (char *) NULL)
@@ -1246,15 +1302,20 @@ MagickPrivate MagickBooleanType ResourceComponentGenesis(void)
 */
 MagickPrivate void ResourceComponentTerminus(void)
 {
-  if (resource_semaphore == (SemaphoreInfo *) NULL)
-    resource_semaphore=AcquireSemaphoreInfo();
-  LockSemaphoreInfo(resource_semaphore);
+  register ssize_t
+    i;
+
+  for (i=0; i < (ssize_t) NumberOfResourceTypes; i++)
+    if (resource_semaphore[i] == (SemaphoreInfo *) NULL)
+      resource_semaphore[i]=AcquireSemaphoreInfo();
+  LockSemaphoreInfo(resource_semaphore[FileResource]);
   if (temporary_resources != (SplayTreeInfo *) NULL)
     temporary_resources=DestroySplayTree(temporary_resources);
   if (random_info != (RandomInfo *) NULL)
     random_info=DestroyRandomInfo(random_info);
-  UnlockSemaphoreInfo(resource_semaphore);
-  RelinquishSemaphoreInfo(&resource_semaphore);
+  UnlockSemaphoreInfo(resource_semaphore[FileResource]);
+  for (i=0; i < (ssize_t) NumberOfResourceTypes; i++)
+    RelinquishSemaphoreInfo(&resource_semaphore[i]);
 }
 
 /*
@@ -1294,6 +1355,21 @@ MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
   status=MagickTrue;
   value=(char *) NULL;
   switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
+    {
+      if (resource_semaphore[type] == (SemaphoreInfo *) NULL)
+        ActivateSemaphoreInfo(&resource_semaphore[type]);
+      LockSemaphoreInfo(resource_semaphore[type]);
+      break;
+    }
+    default: ;
+  }
+  switch (type)
   {
     case AreaResource:
     {
@@ -1333,6 +1409,8 @@ MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
       else
         resource_info.height_limit=MagickMin(limit,StringToMagickSizeType(
           value,100.0));
+      resource_info.height_limit=MagickMin(resource_info.height_limit,
+        SSIZE_MAX);
       break;
     }
     case ListLengthResource:
@@ -1409,6 +1487,8 @@ MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
       else
         resource_info.width_limit=MagickMin(limit,StringToMagickSizeType(value,
           100.0));
+      resource_info.width_limit=MagickMin(resource_info.width_limit,
+        SSIZE_MAX);
       break;
     }
     default:
@@ -1417,6 +1497,19 @@ MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
       break;
     }
   }
+  switch (type)
+  {
+    case DiskResource:
+    case FileResource:
+    case MapResource:
+    case MemoryResource:
+    case TimeResource:
+    {
+      UnlockSemaphoreInfo(resource_semaphore[type]);
+      break;
+    }
+    default: ;
+  }
   if (value != (char *) NULL)
     value=DestroyString(value);
   return(status);
