@@ -277,6 +277,9 @@ MagickExport const char *GetMagickFeatures(void)
 #endif
 #if defined(ZERO_CONFIGURATION_SUPPORT)
   "Zero-configuration "
+#endif
+#if (MAGICKCORE_QUANTUM_DEPTH == 64)
+  "Q64 (experimental, not for production) "
 #endif
   ;
 }
