@@ -1,10 +1,10 @@
-#  Copyright 1999 ImageMagick Studio LLC, a non-profit organization
+#  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
 #  dedicated to making software imaging solutions freely available.
 #
 #  You may not use this file except in compliance with the License.  You may
 #  obtain a copy of the License at
 #
-#    https://imagemagick.org/license/
+#    https://imagemagick.org/script/license.php
 #
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
@@ -45,8 +45,6 @@ sub testCompositeCompare {
 
   $errorinfo='';
   $status='';
-  $normalized_mean_error_max+=1.0e-12;
-  $normalized_maximum_error_max+=1.0e-12;
 
   #print( $filter, " ...\n" );
 
@@ -293,8 +291,6 @@ sub testReadCompare {
   my($srcimage, $refimage, $normalized_mean_error, $normalized_maximum_error);
 
   $errorinfo='';
-  $normalized_mean_error_max+=1.0e-12;
-  $normalized_maximum_error_max+=1.0e-12;
 
   # Create images
   $srcimage=Image::Magick->new;
@@ -571,8 +567,6 @@ sub testReadWriteCompare {
     $normalized_maximum_error);
 
   $errorinfo='';
-  $normalized_mean_error_max+=1.0e-12;
-  $normalized_maximum_error_max+=1.0e-12;
 
   $image=Image::Magick->new;
   $refimage=Image::Magick->new;  
@@ -975,19 +969,6 @@ sub testMontage {
       $ref_32 = $ref_16;
     }
 
-  if (Image::Magick->new()->QuantumDepth == 32)
-    {
-      $ref_signature=$ref_32;
-    }
-  elsif (Image::Magick->new()->QuantumDepth == 16)
-    {
-      $ref_signature=$ref_16;
-    }
-  else
-    {
-      $ref_signature=$ref_8;
-    }
-
   # Create image for image list
   $images=Image::Magick->new;
 
@@ -1043,10 +1024,10 @@ sub testMontage {
     # $montage->Display();
     $signature=$montage->GetAttribute('signature');
     if ( defined( $signature ) ) {
-      if ( $signature ne $ref_signature ) {
+      if ( $signature ne $ref_8 && $signature ne $ref_16 && $signature ne $ref_32 ) {
         print "ReadImage()\n";
         print "Test $test, signatures do not match.\n";
-      	print "     Expected: $ref_signature\n";
+      	print "     Expected: $ref_8\n";
       	print "     Computed: $signature\n";
         print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
         $status = $montage->Write("test_${test}_out.miff");
@@ -1163,8 +1144,6 @@ sub testFilterCompare {
 
   $errorinfo='';
   $status='';
-  $normalized_mean_error_max+=1.0e-12;
-  $normalized_maximum_error_max+=1.0e-12;
 
   #print( $filter, " ...\n" );
 
