@@ -40,12 +40,7 @@
 /*
   Include declarations.
 */
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include <math.h>
-#include <locale.h>
+#include "MagickWand/studio.h"
 #include "MagickWand/MagickWand.h"
 #include "MagickCore/colorspace-private.h"
 #include "MagickCore/gem.h"
@@ -1683,7 +1678,8 @@ static size_t ValidateImageFormatsInMemory(ImageInfo *image_info,
       reference_image->depth=reference_types[j].depth;
       reference_image->compression=reference_formats[i].compression;
       length=8192;
-      blob=ImageToBlob(image_info,reference_image,&length,exception);
+      blob=(unsigned char *) ImageToBlob(image_info,reference_image,&length,
+        exception);
       if ((blob == (unsigned char *) NULL) ||
           (exception->severity >= ErrorException))
         {
